@@ -78,11 +78,10 @@ class App(object):
         handler = self._handler(func, method, **kwargs)
         self.app.api_route(path=path, methods=[method])(handler)
 
-    def add_apps(self, app_dir='apps', prefix='/', **kwargs):
+    def add_apps(self, app_dir='apps', **kwargs):
         """加载当前app_dir文件夹下的所有app（递归）, 入口函数都是main
         1. 过滤掉 _ 开头的py文件
         2. 支持单文件
-        todo: prefix bug????
 
         appcli easy-run app_dir
         """
@@ -97,7 +96,6 @@ class App(object):
             if not p.stem.startswith('_'):  # 过滤_开头的py
                 home_parts = p.parts[n:]
                 route = '/' + "/".join(home_parts)[:-3]
-                route = 'xx'# str(Path(prefix) / Path(route))
                 routes.append(route)
 
                 func = importlib.import_module('.'.join(home_parts)[:-3]).main
